==> okta-sdk-impl-0.10.0-sources.jar: com/okta/sdk/impl/config/OptionalPropertiesSource.java <==
/*
 * Copyright 2014 Stormpath, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.okta.sdk.impl.config;

import com.okta.sdk.lang.Assert;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.LinkedHashMap;
import java.util.Map;

public class OptionalPropertiesSource implements PropertiesSource {

    private static final Logger log = LoggerFactory.getLogger(OptionalPropertiesSource.class);

    private final PropertiesSource propertiesSource;

    public OptionalPropertiesSource(PropertiesSource source) {
        Assert.notNull(source, "source cannot be null.");
        this.propertiesSource = source;
    }

    @Override
    public Map<String,String> getProperties() {
        try {
            return propertiesSource.getProperties();
        } catch (Exception e) {
            log.debug("Unable to obtain properties from optional properties source {}", propertiesSource);
        }
        return new LinkedHashMap<String, String>();
    }
}

==> okta-sdk-impl-8.0.0-sources.jar: com/okta/sdk/impl/config/OptionalPropertiesSource.java <==
/*
 * Copyright 2014 Stormpath, Inc.
 * Modifications Copyright 2018 Okta, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.okta.sdk.impl.config;

import com.okta.commons.lang.Assert;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.LinkedHashMap;
import java.util.Map;

public class OptionalPropertiesSource implements PropertiesSource {

    private static final Logger log = LoggerFactory.getLogger(OptionalPropertiesSource.class);

    private final PropertiesSource propertiesSource;

    public OptionalPropertiesSource(PropertiesSource source) {
        Assert.notNull(source, "source cannot be null.");
        this.propertiesSource = source;
    }

    @Override
    public Map<String,String> getProperties() {
        try {
            return propertiesSource.getProperties();
        } catch (Exception e) {
            log.debug("Unable to obtain properties from optional properties source {}", propertiesSource);
        }
        return new LinkedHashMap<>();
    }
}
